@@ -124,7 +124,7 @@ def help():
           "\n\n"
           "Target Parameter: In place of target should be a crt.sh ID, domain/website (including https://) or local filename\n"
           "\n\n"
-          "ocsp_check version 0.0.9\n"
+          "ocsp_check version 0.0.10\n"
           "Author: Martijn Katerbarg")
 
 
@@ -140,7 +140,7 @@ def getCAIssuer(certificate):
                 CACertificate = authorityInfoAccessMethod.__getattribute__("access_location").value
 
         if CACertificate is None:
-            print("ERROR: No OCSP Server URL found in certificate. Quitting.")
+            print("ERROR: No CA Issuer URL found in certificate. Quitting.")
             exit(-1)
         else:
              return CACertificate
